summaryrefslogtreecommitdiff
path: root/compiler/GHC/StgToCmm
diff options
context:
space:
mode:
authorSylvain Henry <sylvain@haskus.fr>2020-04-05 17:25:06 +0200
committerSylvain Henry <sylvain@haskus.fr>2020-04-18 20:04:14 +0200
commit3ca52151881451ce5b3a7740d003e811b586140d (patch)
tree2dda7d3796d300063111460929489e146701522c /compiler/GHC/StgToCmm
parent15ab6cd548f284732a7f89d78c2b89b1bfc4ea1d (diff)
downloadhaskell-3ca52151881451ce5b3a7740d003e811b586140d.tar.gz
GHC.Core.Opt renaming
* GHC.Core.Op => GHC.Core.Opt * GHC.Core.Opt.Simplify.Driver => GHC.Core.Opt.Driver * GHC.Core.Opt.Tidy => GHC.Core.Tidy * GHC.Core.Opt.WorkWrap.Lib => GHC.Core.Opt.WorkWrap.Utils As discussed in: * https://mail.haskell.org/pipermail/ghc-devs/2020-April/018758.html * https://gitlab.haskell.org/ghc/ghc/issues/13009#note_264650
Diffstat (limited to 'compiler/GHC/StgToCmm')
-rw-r--r--compiler/GHC/StgToCmm/Expr.hs12
1 files changed, 6 insertions, 6 deletions
diff --git a/compiler/GHC/StgToCmm/Expr.hs b/compiler/GHC/StgToCmm/Expr.hs
index cb06799316..05a5e7c69b 100644
--- a/compiler/GHC/StgToCmm/Expr.hs
+++ b/compiler/GHC/StgToCmm/Expr.hs
@@ -64,7 +64,7 @@ cgExpr :: CgStgExpr -> FCode ReturnKind
cgExpr (StgApp fun args) = cgIdApp fun args
-- seq# a s ==> a
--- See Note [seq# magic] in GHC.Core.Op.ConstantFold
+-- See Note [seq# magic] in GHC.Core.Opt.ConstantFold
cgExpr (StgOpApp (StgPrimOp SeqOp) [StgVarArg a, _] _res_ty) =
cgIdApp a []
@@ -325,8 +325,8 @@ calls to nonVoidIds in various places. So we must not look up
Note [Dead-binder optimisation]
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
A case-binder, or data-constructor argument, may be marked as dead,
-because we preserve occurrence-info on binders in GHC.Core.Op.Tidy (see
-GHC.Core.Op.Tidy.tidyIdBndr).
+because we preserve occurrence-info on binders in GHC.Core.Tidy (see
+GHC.Core.Tidy.tidyIdBndr).
If the binder is dead, we can sometimes eliminate a load. While
CmmSink will eliminate that load, it's very easy to kill it at source
@@ -337,7 +337,7 @@ to keep it for -O0. See also Phab:D5358.
This probably also was the reason for occurrence hack in Phab:D5339 to
exist, perhaps because the occurrence information preserved by
-'GHC.Core.Op.Tidy.tidyIdBndr' was insufficient. But now that CmmSink does the
+'GHC.Core.Tidy.tidyIdBndr' was insufficient. But now that CmmSink does the
job we deleted the hacks.
-}
@@ -405,7 +405,7 @@ cgCase scrut@(StgApp v []) _ (PrimAlt _) _
{- Note [Handle seq#]
~~~~~~~~~~~~~~~~~~~~~
-See Note [seq# magic] in GHC.Core.Op.ConstantFold.
+See Note [seq# magic] in GHC.Core.Opt.ConstantFold.
The special case for seq# in cgCase does this:
case seq# a s of v
@@ -420,7 +420,7 @@ is the same as the return convention for just 'a')
cgCase (StgOpApp (StgPrimOp SeqOp) [StgVarArg a, _] _) bndr alt_type alts
= -- Note [Handle seq#]
- -- And see Note [seq# magic] in GHC.Core.Op.ConstantFold
+ -- And see Note [seq# magic] in GHC.Core.Opt.ConstantFold
-- Use the same return convention as vanilla 'a'.
cgCase (StgApp a []) bndr alt_type alts